@@ -1,6 +1,6 @@
 import os
 import platform
-from re import L
+import pathlib
 
 import typer
 from cookiecutter.main import cookiecutter
@@ -17,31 +17,35 @@ def callback():
 
 def get_template_path(template_name):
     script_path = os.path.abspath(__file__)
-    module_path = os.path.dirname(script_path)
-    templates_path = os.path.join(module_path, "templates")
+    current_dir_path = os.path.dirname(script_path)
+    templates_path = os.path.join(current_dir_path, "templates")
     return os.path.join(templates_path, template_name)
     
 
 def activate_venv(path):
 
-    parent = os.getcwd()
-    os.system("python -m venv env")
+    # set current directory
+    os.chdir(path)
+    os.system("python -m venv venv")
+    print("🔨 setting up your virutal environment")
 
     env_activate_script = ""
     if OS == "Windows":
         env_activate_script = "Scripts"
 
-    print("---path ", parent)
     activate_file = os.path.join(path, "env", env_activate_script, "activate")
-    print("---activate_file ", activate_file)
     os.system(f"{activate_file} && pip install -r requirements.txt")
+    print("✏️ downloading packages")
 
 
 @app.command("")
 def main(template_name):
     template_path = get_template_path(template_name)
     path = cookiecutter(template_path)
-    project_path = os.path.join(template_path, template_name)
-    print("---project_path", project_path)
     activate_venv(path)
+    print("💥 your DRF project is ready!")
+    folder_name = pathlib.PurePath(path)
+    if OS == "Windows":
+        activate_file = os.path.join(path, "env", "Scripts", "activate")
+        print(f"cd {folder_name} && {activate_file}")
 
